<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}
function dtwpb_get_screen_ids(){
	$screen_ids   = array(
		'toplevel_page_woocommerce-page-builder-options',
		'woocommerce-page-builder-options'
	);
	return $screen_ids;
}

function dtwpb_woocommerce_version_check( $version = '3.0' ){
	if ( class_exists( 'WooCommerce' ) ) {
		global $woocommerce;
		if ( version_compare( $woocommerce->version, $version, ">=" ) ) {
			return true;
		}
	}
	return false;
}

if ( ! function_exists( 'dtwpb_woocommerce_builder_notices' ) ) {
	function dtwpb_woocommerce_builder_notices(){
		if( get_option('dtwpb_woo_notices', '') === 'woo-builder-notices' ){
			return true;
		}
		return false;
	}
}

function dtwpb_insert_page_tpl_2_product_tpl($posted_data = array(), $post_type = ''){
	if($post_type == '') return;
	
	$post_description = isset( $posted_data['post_content'] ) ? $posted_data['post_content'] : '';
	$post_excerpt = isset( $posted_data['post_excerpt'] ) ? $posted_data['post_excerpt'] : '';
	$post_title = isset( $posted_data['post_title'] ) ? $posted_data['post_title'] : '';
	$_wpb_post_custom_css = isset( $posted_data['_wpb_post_custom_css'] ) ? $posted_data['_wpb_post_custom_css'] : '';
	
	if( !get_page_by_title($post_title, OBJECT, $post_type) ){
		$post_post = array(
			'post_content'   => $post_description,
			'post_excerpt'   => $post_excerpt,
			'post_name' 	   => sanitize_title($post_title), //slug
			'post_title'     => $post_title,
			'post_status'    => 'publish',
			'post_type'      => $post_type
		);
		
		if( ($new_id = wp_insert_post( $post_post, false)) ){
			add_post_meta( $new_id, '_wpb_post_custom_css', $_wpb_post_custom_css );
		}
	}
	
}

function dtwpb_apply_custom_css_option($custom_css){
	//
	$css = apply_filters( 'dtwpb_base_build_shortcodes_custom_css', $custom_css );
	if ($css!="") {
		echo '<style>';
		echo $css;
		echo '</style>';
	}
}

function dtwpb_woocommerce_page_builder_shortcode_vc_custom_css_class( $param_value, $prefix = '', $atts = '' ){
	dtwpb_apply_custom_css_option($param_value);
	if(function_exists('vc_shortcode_custom_css_class')){ 
		return vc_shortcode_custom_css_class($param_value,$prefix);
	}
	$css_class = preg_match( '/\s*\.([^\{]+)\s*\{\s*([^\}]+)\s*\}\s*/', $param_value ) ? $prefix . preg_replace( '/\s*\.([^\{]+)\s*\{\s*([^\}]+)\s*\}\s*/', '$1', $param_value ) : '';

	return $css_class;
}

function dtwpb_woo_query_orderby($orderby = 'recent', $post_per_page = -1){
	global $woocommerce;
	$query_args = array(
			'post_type' => 'product',
			'posts_per_page' => -1,
			'post_status' => 'publish',
		);
	switch ($orderby){
		case 'recent':
			$query_args['meta_query'] = array();
			$query_args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
			break;
		case 'best_selling':
			$query_args['meta_key']='total_sales';
			$query_args['orderby']='meta_value_num';
			$query_args['ignore_sticky_posts']   = 1;
			$query_args['meta_query'] = array();
			$query_args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
			$query_args['meta_query'][] = $woocommerce->query->visibility_meta_query();
			break;
		case 'featured_product':
			$query_args['ignore_sticky_posts']=1;
			$query_args['meta_query'] = array();
			$query_args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
			$query_args['meta_query'][] = array(
				'key' => '_featured',
				'value' => 'yes'
			);
			$query_args['meta_query'][] = $woocommerce->query->visibility_meta_query();
			break;
		case 'top_rate':
			add_filter( 'posts_clauses',  array( $woocommerce->query, 'order_by_rating_post_clauses' ) );
			$query_args['meta_query'] = array();
			$query_args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
			$query_args['meta_query'][] = $woocommerce->query->visibility_meta_query();
			break;
		case 'on_sale':
			$query_args['meta_query'] = array();
			$query_args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
			$query_args['meta_query'][] = $woocommerce->query->visibility_meta_query();
			$query_args['post__in'] = wc_get_product_ids_on_sale();
			break;
		case 'recent_review':
			if($post_per_page == -1) $_limit = 4;
			else $_limit = $post_per_page;
			global $wpdb;
			$query = $wpdb->prepare( "
			SELECT c.comment_post_ID
			FROM {$wpdb->prefix}posts p, {$wpdb->prefix}comments c
			WHERE p.ID = c.comment_post_ID AND c.comment_approved > %d
			AND p.post_type = %s AND p.post_status = %s
			AND p.comment_count > %d ORDER BY c.comment_date ASC" ,
			0, 'product', 'publish', 0 );

			$results = $wpdb->get_results($query, OBJECT);
			$_pids = array();
			foreach ($results as $re) {
			if(!in_array($re->comment_post_ID, $_pids))
				$_pids[] = $re->comment_post_ID;
				if(count($_pids) == $_limit)
					break;
			}

			$query_args['meta_query'] = array();
			$query_args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
			$query_args['meta_query'][] = $woocommerce->query->visibility_meta_query();
			$query_args['post__in'] = $_pids;
			break;
		case 'price':
			$query_args['meta_key'] = '_price';
			$query_args['orderby'] = 'meta_value_num';
			break;
		case 'rand':
			$query_args['orderby']  = 'rand';
			break;
		default:
			$ordering_args = $woocommerce->query->get_catalog_ordering_args($orderby, '');
			$query_args['orderby'] = $ordering_args['orderby'];
		break;
		}
		
		return $query_args;
}

function dtwpb_paginate_links( $args = array(), $query = null ){
	global $wp_rewrite, $wp_query;
	$temp_query = $wp_query;

	if ( !empty($query)) {
		$wp_query = $query;
	}

	if ( 1 >= $wp_query->max_num_pages )
		return;

	$paged = ( get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1 );

	$max_num_pages = intval( $wp_query->max_num_pages );

	$defaults = array(
			'base' => esc_url(add_query_arg( 'paged', '%#%' )),
			'format' => '',
			'total' => $max_num_pages,
			'current' => $paged,
			'prev_next' => true,
			'prev_text' => '&larr;',
			'next_text' => '&rarr;',
			'show_all' => false,
			'end_size' => 3,
			'mid_size' => 3,
			'add_fragment' => '',
			'type' => 'list',
			'before' => '',
			'after' => '',
			'echo' => true,
			'use_search_permastruct' => true
	);

	$defaults = apply_filters( 'dt_pagination_args_defaults', $defaults );

	if( $wp_rewrite->using_permalinks() && ! is_search() )
		$defaults['base'] = user_trailingslashit( trailingslashit( get_pagenum_link() ) . 'page/%#%' );

	if ( is_search() )
		$defaults['use_search_permastruct'] = false;

	if ( is_search() ) {
		if ( class_exists( 'BP_Core_User' ) || $defaults['use_search_permastruct'] == false ) {
			$search_query = get_query_var( 's' );
			$paged = get_query_var( 'paged' );
			$base = esc_url(add_query_arg( 's', urlencode( $search_query ) ));
			$base = esc_url(add_query_arg( 'paged', '%#%' ));
			$defaults['base'] = $base;
		} else {
			$search_permastruct = $wp_rewrite->get_search_permastruct();
			if ( ! empty( $search_permastruct ) ) {
				$base = get_search_link();
				$base = esc_url(add_query_arg( 'paged', '%#%', $base ));
				$defaults['base'] = $base;
			}
		}
	}

	$args = wp_parse_args( $args, $defaults );

	$args = apply_filters( 'dt_pagination_args', $args );

	if ( 'array' == $args['type'] )
		$args['type'] = 'array';

	$pattern = '/\?(.*?)\//i';

	preg_match( $pattern, $args['base'], $raw_querystring );
	
	if(!empty($raw_querystring)){
		if( $wp_rewrite->using_permalinks() && $raw_querystring )
			$raw_querystring[0] = str_replace( '', '', $raw_querystring[0] );
		$args['base'] = str_replace( $raw_querystring[0], '', $args['base'] );
		$args['base'] .= substr( $raw_querystring[0], 0, -1 );
	}
	$page_links = paginate_links( $args );

	$page_links = str_replace( array( '&#038;paged=1\'', '/page/1\'' ), '\'', $page_links );

	$page_links = $args['before'] . $page_links . $args['after'];
	
	$wp_query = $temp_query;
	
	if ( $args['echo'] )
		echo($page_links);
	else
		return $page_links;
}

function dtwpb_support_Ultimate_VC_Addons(){
	if( class_exists('Ultimate_VC_Addons') ){
		wp_enqueue_style('ultimate-style-min');
		wp_enqueue_script('ultimate-script');
		wp_enqueue_script('ultimate-appear');
		wp_enqueue_script('ultimate-custom');
		wp_enqueue_script('ultimate-vc-params');
	}
}
